@@ -74,7 +74,7 @@ def read_survey(path):
 def get_hd(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     SURVEY = 'HD' + str(year)
     # build the url
@@ -86,7 +86,7 @@ def get_hd(year):
 def get_ic(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     SURVEY = 'IC' + str(year)
     # build the url
@@ -98,7 +98,7 @@ def get_ic(year):
 def get_adm(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2014 and year <= 2018, "year must be >=2014 and <= 2018"
+    assert year >= 2014 and year <= 2020, "year must be >=2014 and <= 2020"
     # build the SURVEY id
     SURVEY = 'ADM' + str(year)
     # build the url
@@ -110,7 +110,7 @@ def get_adm(year):
 def get_sfa(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     sfa_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'SFA' + str(sfa_year)
@@ -123,7 +123,7 @@ def get_sfa(year):
 def get_efc(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     SURVEY = 'EF' + str(year) + "C"
     # build the url
@@ -135,7 +135,7 @@ def get_efc(year):
 def get_icay(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2001 and year <= 2020, "year must be >=2001 and <= 2020"
     # build the SURVEY id
     SURVEY = 'IC' + str(year) + "_AY"
     # build the url
@@ -146,7 +146,7 @@ def get_icay(year):
 def get_om(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2015 and year <= 2018, "year must be >=2015 and <= 2018"
+    assert year >= 2015 and year <= 2020, "year must be >=2015 and <= 2020"
     # build the SURVEY id
     SURVEY = 'OM' + str(year) 
     # build the url
@@ -157,7 +157,7 @@ def get_om(year):
 def get_efd(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     SURVEY = 'EF' + str(year)  + "D"
     # build the url
@@ -168,7 +168,7 @@ def get_efd(year):
 def get_ff1(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     ff1_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'F' + str(ff1_year)  + "_F1A"
@@ -180,7 +180,7 @@ def get_ff1(year):
 def get_ff2(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     ff2_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'F' + str(ff2_year)  + "_F2"
@@ -192,7 +192,7 @@ def get_ff2(year):
 def get_ca(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2002 and year <= 2020, "year must be >=2002 and <= 2020"
     # build the SURVEY id
     SURVEY = 'C' + str(year)  + "_A"
     # build the url
@@ -206,7 +206,7 @@ def get_ca(year):
 class HD(object):
     """
     Directory Information from the Institutional Characteristics survey.
-    Currently supports the years 2002 - 2018.
+    Currently supports the years 2002 - 2020.
 
     Methods are extract, transform, and load.
     """
@@ -270,6 +270,7 @@ class HD(object):
                   service=None, 
                   lower_us=None, 
                   regions = None, 
+                  sector_labs = None,
                   cols=None):
         """
         The transformation methods for the dataset collected.  
@@ -280,6 +281,7 @@ class HD(object):
             service (bool): if True, remove service schools
             lower_us (bool): if True, keep only the contintental 48 states incl. D.C.
             regions (bool): if True, add state/region info to the institution
+            sector_labs (bool): if True, will add a column containing the sector labels. 
             cols (list): A list of valid column names to keep, all others will be excluded
         """
 
@@ -313,6 +315,27 @@ class HD(object):
             tmp = tmpdf
             tmp_f = pd.merge(left=tmp, right=r, on="fips", how="left")
             tmpdf = tmp_f
+        
+        # sector labels
+        if sector_labs:
+            # the mapping
+            sector_labs = {0:'Administrative Unit', 
+               1:'Public, 4-year or above',
+               2:'Private not-for-profit 4-year or above',
+               3:'Private for-profit 4-year or above',
+               4:'Public, 2-year',
+               5:'Private not-for-profit 2-year',
+               6:'Private for-profit 2-year',
+               7:'Public less-than 2-year',
+               8:'Private not-for-profit less-than 2-year',
+               9:'Private for-profit less-than 2-year',
+               99:'Sector Unknown'}
+            # create a copy of the values into a new column and replace the values
+            tmp = tmpdf
+            tmp['sector_labels'] = tmp.sector 
+            tmp['sector_labels'] = tmp.sector_labels.replace(sector_labs)
+            tmpdf = tmp
+
 
         # select columns
         if cols is not None:
@@ -329,11 +352,11 @@ class HD(object):
 class IC(object):
     """
     Educational offerings, organization, services and athletic associations from the Institutional Characteristics survey.
-    Currently support the years 2002 to 2018.
+    Currently support the years 2002 to 2020.
     """
 
     # init
-    def __init__(self, years=[2018]):
+    def __init__(self, years=[2020]):
         """
         The constructor for the IC survey
 
@@ -617,7 +640,6 @@ class EFC(object):
             r = datasets.region_xwalk()
             r = r >> select(['ipeds_code','name','ipeds_region', 'postal code'])
             r = r.rename(columns={"ipeds_code": "line", 
-                                  "postal code":"res_abbrev", 
                                   "ipeds_region":"res_region", 
                                   "postal code":"res_zip",
                                   "name":"res_name"})
@@ -797,7 +819,7 @@ class FF1(object):
     Private not-for-profit institutions or Public institutions using FASB:
     """
 
-    def __init__(self, years=[2018]):
+    def __init__(self, years=[2020]):
         """
         Public institutions - GASB
 
@@ -867,7 +889,7 @@ class FF2(object):
     Private not-for-profit institutions or Public institutions using FASB:
     """
 
-    def __init__(self, years=[2018]):
+    def __init__(self, years=[2020]):
         """
         Public institutions - GASB
 
@@ -937,7 +959,7 @@ class C_A(object):
     Awards/degrees conferred by program (6-digit CIP code), award level, race/ethnicity, and gender
     """
 
-    def __init__(self, years=[2018]):
+    def __init__(self, years=[2020]):
         """
         Public institutions - GASB
 
